<?

 /*************************************************************************************
 * Filename: skeleton.php
 *
 * This file is part of the skeleton JAS plugin.
 * Copyright 2003-2015 by Matthijs Schuurman
 *
 * The skeleton JAS plugin is free software under the terms of the
 * GNU Lesser General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/skeleton/
 *************************************************************************************/


 class Plugin_skeleton extends Base_Plugin
 {
  /*
   * Main
   *
   * All non displaying logic that needs to be performed before the output is generated
   */

  function main()
  {
   if(!$this->config) //no config loaded
    $this->e->add("No frontend configuration loaded", "note");

   //logic
   $this->e->add("Main frontend logic successfully executed", "note");

   if($this->e->any("fatal"))
    return false; //output function skipped and errors are displayed

   return true;
  }


  /*
   * Output
   *
   * All displaying logic for gathering and displaying information
   */

  function output()
  {
   //gather output data...

   if($this->e->any("fatal"))
    return false; //errors are displayed

   //render output
   $output=$this->plugin->l->t("Skeleton frontend output");

   return $output; //display output
  }


  /*
   * Pager plugin cache hook
   *
   * cacheTime: time to which is checked whether cache is still up-to-date
   * cacheKey: unique key used for caching.
   *
   * Both need to be set for successful caching.
   *
   *
   * The cache logic is called right before the output() call.
   * If the cache function doesn't exist the default pager cache logic will be used.
   * To disable caching for this plugin ensure the cache function always returns false
   */

  function cache(&$cacheTime, &$cacheKey)
  {
   //determine last update time

   //determine unique cache key

   //Note that the pager plugin already sets a prefix for user/group specific caching so the unique key should be appended to the cache key ($cacheKey.=$uniqueID) unless this behaviour should be ignored.

   if($this->e->any("fatal"))
    return false; //no caching and output function is called

   return true; //check if cache is up to date, if so the cached version is used, otherwise output function is called
  }

 }
?>
